==> nextcloud-29.0.5.tgz: nextcloud/apps/files_reminders/l10n/pt_BR.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Lembretes em arquivo.",
    "Reminder for {name}" : "Lembrete para {name}",
    "View file" : "Ver arquivo",
    "View folder" : "Ver pasta",
    "Set file reminders" : "Define lembrete em arquivo",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Lembrete em Arquivo**\n\nDefine lembrete em arquivo.",
    "We will remind you of this file" : "Vamos lembrá-lo deste arquivo",
    "Please choose a valid date & time" : "Por favor escolha uma data e hora válida.",
    "Cancel" : "Cancelar",
    "Clear reminder" : "Limpar lembrete",
    "Set reminder" : "Definir lembrete",
    "Set reminder for \"{fileName}\"" : "Definir lembrete para \"{fileName}\"",
    "Set reminder at custom date & time" : "Define lembrete em data e hora customizada",
    "Reminder set for \"{fileName}\"" : "Lembrete definido para \"{fileName}\"",
    "Failed to set reminder" : "Falha ao definir lembrete",
    "Reminder cleared for \"{fileName}\"" : "Lembrete limpo para \"{fileName}\"",
    "Failed to clear reminder" : "Falha ao limpar lembrete",
    "Reminder set" : "Conjunto de lembretes",
    "Set custom reminder" : "Definir lembrete personalizado",
    "Later today" : "Hoje mais tarde",
    "Set reminder for later today" : "Definir lembrete para hoje mais tarde",
    "Tomorrow" : "Amanhã",
    "Set reminder for tomorrow" : "Definir lembrete para amanhã",
    "This weekend" : "Este fim de semana",
    "Set reminder for this weekend" : "Definir lembrete para este fim de semana",
    "Next week" : "Próxima semana",
    "Set reminder for next week" : "Definir lembrete para a próxima semana"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.10.tgz: nextcloud/apps/files_reminders/l10n/pt_BR.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Lembretes em arquivo.",
    "Reminder for {name}" : "Lembrete para {name}",
    "View file" : "Ver arquivo",
    "View folder" : "Ver pasta",
    "Set file reminders" : "Define lembrete em arquivo",
    "We will remind you of this file" : "Vamos lembrá-lo deste arquivo",
    "Please choose a valid date & time" : "Por favor escolha uma data e hora válida.",
    "Cancel" : "Cancelar",
    "Clear reminder" : "Limpar lembrete",
    "Set reminder" : "Definir lembrete",
    "Set reminder for \"{fileName}\"" : "Definir lembrete para \"{fileName}\"",
    "Set reminder at custom date & time" : "Define lembrete em data e hora customizada",
    "Reminder set for \"{fileName}\"" : "Lembrete definido para \"{fileName}\"",
    "Failed to set reminder" : "Falha ao definir lembrete",
    "Reminder cleared for \"{fileName}\"" : "Lembrete limpo para \"{fileName}\"",
    "Failed to clear reminder" : "Falha ao limpar lembrete",
    "Reminder set" : "Conjunto de lembretes",
    "Set custom reminder" : "Definir lembrete personalizado",
    "Later today" : "Hoje mais tarde",
    "Set reminder for later today" : "Definir lembrete para hoje mais tarde",
    "Tomorrow" : "Amanhã",
    "Set reminder for tomorrow" : "Definir lembrete para amanhã",
    "This weekend" : "Este fim de semana",
    "Set reminder for this weekend" : "Definir lembrete para este fim de semana",
    "Next week" : "Próxima semana",
    "Set reminder for next week" : "Definir lembrete para a próxima semana",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Lembrete em Arquivo**\n\nDefine lembrete em arquivo."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
